@@ -35,7 +35,7 @@
 
 const QString plasmarc = QStringLiteral("plasmarc");
 const QString groupName = QStringLiteral("Units");
-const int defaultLongDuration = 250;
+const int defaultLongDuration = 120;
 
 Units::Units(QObject *parent)
     : QObject(parent),
@@ -158,6 +158,8 @@ int Units::devicePixelIconSize(const int size) const
     } else if (ratio < 2.5) {
         return size * 2.0;
     } else if (ratio < 3.0) {
+        return size * 2.5;
+    } else if (ratio < 3.5) {
         return size * 3.0;
     } else {
         return size * ratio;
@@ -178,7 +180,7 @@ void Units::updateDevicePixelRatio()
     // TODO: make it possible to adapt to the dpi for the current screen dpi
     //  instead of assuming that all of them use the same dpi which applies for
     //  X11 but not for other systems.
-    qreal dpi = QGuiApplication::primaryScreen()->physicalDotsPerInchX();
+    qreal dpi = QGuiApplication::primaryScreen()->logicalDotsPerInchX();
     // Usual "default" is 96 dpi
     // that magic ratio follows the definition of "device independent pixel" by Microsoft
     m_devicePixelRatio = (qreal)dpi / (qreal)96;
